# guc
 The GroundUpCoder Python library

A pure Python utility library for making games with Pygame.

Currently a work in progress -

## Release Notes

### 0.0.1

Initial commit with colors and a little bit of linear algebra
